/******************************************************************************
 * @file hw_config.h
 * @brief Smart Card Driver pin/clk/uart config header file
 * @author Energy Micro AS
 * @version 1.00
 ******************************************************************************
 * @section License
 * <b>(C) Copyright 2014 Energy Micro AS, http://www.energymicro.com</b>
 *******************************************************************************
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 * 4. The source and compiled code may only be used on Energy Micro "EFM32"
 *    microcontrollers and "EFR4" radios.
 *
 * DISCLAIMER OF WARRANTY/LIMITATION OF REMEDIES: Energy Micro AS has no
 * obligation to support this Software. Energy Micro AS is providing the
 * Software "AS IS", with no express or implied warranties of any kind,
 * including, but not limited to, any implied warranties of merchantability
 * or fitness for any particular purpose or warranties against infringement
 * of any proprietary rights of a third party.
 *
 * Energy Micro AS will not be liable for any consequential, incidental, or
 * special damages, or any other relief, or for any claim by any third party,
 * arising from your use of this Software.
 *
 *****************************************************************************/
#ifndef __HW_CONFIG_H
#define __HW_CONFIG_H

/* Define Timing Parameters */
/* This implementation only supports 9600 bps and standard clk freq multiplier (372) */
#define SC_BAUD_RATE (9600)
#define SC_CLK_MULTIPLIER (372)
#define SC_CLK_FREQ (SC_BAUD_RATE * SC_CLK_MULTIPLIER)

/* Byte time equals 1 start bit, 8 data, 1 parity and 2 guard bits. */
#define SC_BYTE_TIME (12*1000/SC_BAUD_RATE + 1)

/* ms to wait for any answer from card before timing out. */
#define SC_CMD_TIMEOUT (500)

/* Different timeout periods in ms for Reset procedure */
#define SC_PWR_ON_DELAY (10)
#define SC_CLK_DELAY (10)
#define SC_ATR_DELAY (100)

/* Timer to use for clk output */        
#define SC_TIMER TIMER0
#define SC_TIMER_CMU_CLOCK cmuClock_TIMER0

/* GPIO pins to use for smartcard comm. Clock pin must match with timer CC output. */
/* Data pin must match usart location and usart peripheral. */
#define SC_USART_MODULE USART1
#define SC_USART_LOCATION USART_ROUTE_LOCATION_LOC1
#define SC_GPIO_DATA_PORT gpioPortD
#define SC_GPIO_DATA_PIN 0 

#define SC_GPIO_CLOCK_PORT gpioPortD
#define SC_GPIO_CLOCK_PIN 2

#define SC_GPIO_VDD_PORT gpioPortD
#define SC_GPIO_VDD_PIN 3
#define SC_GPIO_GND_PORT gpioPortD
#define SC_GPIO_GND_PIN 4
#define SC_GPIO_RESET_PORT gpioPortD
#define SC_GPIO_RESET_PIN 5
#define SC_GPIO_INSERT_DETECTION_PORT gpioPortD
#define SC_GPIO_INSERT_DETECTION_PIN 1

#define SC_GPIO_ACTIVITY_LED_PORT gpioPortE
#define SC_GPIO_ACTIVITY_LED_PIN 2

#endif /* __HW_CONFIG_H */
